@@ -12,7 +12,7 @@ class PickleSerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(PickleSerializer, self).__init__()
+        super().__init__()
 
     def decode(self, s, **kwargs):
         encoding = kwargs.pop("encoding", "utf-8")
